@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 # vim:fileencoding=utf-8
-
+from __future__ import unicode_literals
 __author__ = 'zeus'
 
-from django.core.management.base import BaseCommand, CommandError
+from django.core.management.base import BaseCommand
 from pybb.models import Topic, Post
 from django.core import serializers
 
+
 class Command(BaseCommand):
     args = '<topic_id topic_id>'
     help = 'Dump target topics to json'
