@@ -1,16 +1,11 @@
-# -*- coding: utf-8 -*-
-
+# coding=utf-8
+from __future__ import unicode_literals
 from django.contrib.auth.models import Permission
-from django.db.models import ObjectDoesNotExist
+from django.contrib.contenttypes.models import ContentType
 from django.db.models.signals import post_save, post_delete
-
+from pybb.models import Post
 from pybb.subscription import notify_topic_subscribers
-from pybb import defaults
-from pybb.models import Profile, Post
-
-from pybb import util
-User = util.get_user_model()
-username_field = util.get_username_field()
+from pybb import util, defaults, compat
 
 
 def post_saved(instance, **kwargs):
@@ -34,19 +29,24 @@ def post_deleted(instance, **kwargs):
 def user_saved(instance, created, **kwargs):
     if not created:
         return
+
     try:
         add_post_permission = Permission.objects.get_by_natural_key('add_post', 'pybb', 'post')
         add_topic_permission = Permission.objects.get_by_natural_key('add_topic', 'pybb', 'topic')
-    except ObjectDoesNotExist:
+    except (Permission.DoesNotExist, ContentType.DoesNotExist):
         return
     instance.user_permissions.add(add_post_permission, add_topic_permission)
     instance.save()
-    if util.get_pybb_profile_model() == Profile:
-        Profile(user=instance).save()
+
+    if defaults.PYBB_PROFILE_RELATED_NAME:
+        ModelProfile = util.get_pybb_profile_model()
+        profile = ModelProfile()
+        setattr(instance, defaults.PYBB_PROFILE_RELATED_NAME, profile)
+        profile.save()
 
 
-def setup_signals():
+def setup():
     post_save.connect(post_saved, sender=Post)
     post_delete.connect(post_deleted, sender=Post)
     if defaults.PYBB_AUTO_USER_PERMISSIONS:
-        post_save.connect(user_saved, sender=User)
+        post_save.connect(user_saved, sender=compat.get_user_model())
