@@ -368,7 +368,8 @@ class AddPostView(PostEditMixin, generic.CreateView):
                     raise Http404
                 else:
                     post = get_object_or_404(Post, pk=quote_id)
-                    self.quote = defaults.PYBB_QUOTE_ENGINES[defaults.PYBB_MARKUP](post.body, getattr(post.user, username_field))
+                    profile = util.get_pybb_profile(post.user)
+                    self.quote = util._get_markup_quoter(defaults.PYBB_MARKUP)(post.body, profile.get_display_name())
 
                 if self.quote and request.is_ajax():
                     return HttpResponse(self.quote)
@@ -674,7 +675,7 @@ def add_subscription(request, topic_id):
 @login_required
 def post_ajax_preview(request):
     content = request.POST.get('data')
-    html = defaults.PYBB_MARKUP_ENGINES[defaults.PYBB_MARKUP](content)
+    html = util._get_markup_formatter()(content)
     return render(request, 'pybb/_markitup_preview.html', {'html': html})
 
 
